==> ejc-proequipmentcorp-impl-3.0.0-20221027.025620-67-sources.jar: com/ejianc/business/proequipmentcorppur/asset/bean/AssetMaintainEquipmentEntity.java <==
package com.ejianc.business.proequipmentcorppur.asset.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 设备维修保养-设备
 * 
 * @author generator
 * 
 */
 @TableName("ejc_proequipmentcorp_asset_maintain_equipment")
public class AssetMaintainEquipmentEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="factory_code")
    private String factoryCode; // 设备出厂参数
    @TableField(value="maintain_id")
    private Long maintainId; // 主表d
    @TableField(value="equipment_type_id")
    private Long equipmentTypeId; // 设备分类id
    @TableField(value="equipment_type_code")
    private String equipmentTypeCode; // 设备分类编码
    @TableField(value="equipment_type_name")
    private String equipmentTypeName; // 设备分类名称
    @TableField(value="equipment_id")
    private Long equipmentId; // 设备id
    @TableField(value="equipment_code")
    private String equipmentCode; // 设备编码
    @TableField(value="equipment_name")
    private String equipmentName; // 设备名称
    @TableField(value="spec")
    private String spec; // 
    @TableField(value="unit_id")
    private Long unitId; // 计量单位id
    @TableField(value="unit")
    private String unit; // 计量单位
    @TableField(value="project_id")
    private Long projectId; // 使用项目id
    @TableField(value="project_Name")
    private String projectName; // 使用项目
    @TableField(value="leave_factory_date")
    private Date leaveFactoryDate; // 出厂日期
    @TableField(value="maintain_position")
    private String maintainPosition; // 维修保养部位
    @TableField(value="maintain_requirement")
    private String maintainRequirement; // 维修保养要求
    @TableField(value="maintain_cost")
    private String maintainCost; // 维修保养费用
    @TableField(value="maintain_user")
    private String maintainUser; // 维修保养费用
    @TableField(value="memo")
    private String memo; // 备注
    
    
    

    public String getFactoryCode() {
        return factoryCode;
    }

    public void setFactoryCode(String factoryCode) {
        this.factoryCode = factoryCode;
    }

    public Long getMaintainId() {
        return maintainId;
    }

    public void setMaintainId(Long maintainId) {
        this.maintainId = maintainId;
    }

    public Long getEquipmentTypeId() {
        return equipmentTypeId;
    }

    public void setEquipmentTypeId(Long equipmentTypeId) {
        this.equipmentTypeId = equipmentTypeId;
    }
    public String getEquipmentTypeCode() {
        return equipmentTypeCode;
    }

    public void setEquipmentTypeCode(String equipmentTypeCode) {
        this.equipmentTypeCode = equipmentTypeCode;
    }
    public String getEquipmentTypeName() {
        return equipmentTypeName;
    }

    public void setEquipmentTypeName(String equipmentTypeName) {
        this.equipmentTypeName = equipmentTypeName;
    }
    public Long getEquipmentId() {
        return equipmentId;
    }

    public void setEquipmentId(Long equipmentId) {
        this.equipmentId = equipmentId;
    }
    public String getEquipmentCode() {
        return equipmentCode;
    }

    public void setEquipmentCode(String equipmentCode) {
        this.equipmentCode = equipmentCode;
    }
    public String getEquipmentName() {
        return equipmentName;
    }

    public void setEquipmentName(String equipmentName) {
        this.equipmentName = equipmentName;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public Long getUnitId() {
        return unitId;
    }

    public void setUnitId(Long unitId) {
        this.unitId = unitId;
    }
    public String getUnit() {
        return unit;
    }

    public void setUnit(String unit) {
        this.unit = unit;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Date getLeaveFactoryDate() {
        return leaveFactoryDate;
    }

    public void setLeaveFactoryDate(Date leaveFactoryDate) {
        this.leaveFactoryDate = leaveFactoryDate;
    }
    public String getMaintainPosition() {
        return maintainPosition;
    }

    public void setMaintainPosition(String maintainPosition) {
        this.maintainPosition = maintainPosition;
    }
    public String getMaintainRequirement() {
        return maintainRequirement;
    }

    public void setMaintainRequirement(String maintainRequirement) {
        this.maintainRequirement = maintainRequirement;
    }
    public String getMaintainCost() {
        return maintainCost;
    }

    public void setMaintainCost(String maintainCost) {
        this.maintainCost = maintainCost;
    }
    public String getMaintainUser() {
        return maintainUser;
    }

    public void setMaintainUser(String maintainUser) {
        this.maintainUser = maintainUser;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    
}

==> ejc-proequipmentcorp-impl-3.0.0-20230323.082600-355-sources.jar: com/ejianc/business/proequipmentcorppur/asset/bean/AssetMaintainEquipmentEntity.java <==
package com.ejianc.business.proequipmentcorppur.asset.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 设备维修保养-设备
 * 
 * @author generator
 * 
 */
 @TableName("ejc_proequipmentcorp_asset_maintain_equipment")
public class AssetMaintainEquipmentEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="factory_code")
    private String factoryCode; // 设备出厂参数
    @TableField(value="maintain_id")
    private Long maintainId; // 主表d
    @TableField(value="equipment_type_id")
    private Long equipmentTypeId; // 设备分类id
    @TableField(value="equipment_type_code")
    private String equipmentTypeCode; // 设备分类编码
    @TableField(value="equipment_type_name")
    private String equipmentTypeName; // 设备分类名称
    @TableField(value="equipment_id")
    private Long equipmentId; // 设备id
    @TableField(value="equipment_code")
    private String equipmentCode; // 设备编码
    @TableField(value="equipment_name")
    private String equipmentName; // 设备名称
    @TableField(value="spec")
    private String spec; // 
    @TableField(value="unit_id")
    private Long unitId; // 计量单位id
    @TableField(value="unit")
    private String unit; // 计量单位
    @TableField(value="project_id")
    private Long projectId; // 使用项目id
    @TableField(value="project_Name")
    private String projectName; // 使用项目
    @TableField(value="leave_factory_date")
    private Date leaveFactoryDate; // 出厂日期
    @TableField(value="maintain_position")
    private String maintainPosition; // 维修保养部位
    @TableField(value="maintain_requirement")
    private String maintainRequirement; // 维修保养要求
    @TableField(value="maintain_cost")
    private String maintainCost; // 维修保养费用
    @TableField(value="maintain_user")
    private String maintainUser; // 维修保养费用
    @TableField(value="memo")
    private String memo; // 备注


    @TableField(value="maintain_user_id")
    private Long maintainUserId; // 保养人

    @TableField(value="maintain_user_name")
    private String maintainUserName; // 保养人名称

    public String getFactoryCode() {
        return factoryCode;
    }

    public void setFactoryCode(String factoryCode) {
        this.factoryCode = factoryCode;
    }

    public Long getMaintainId() {
        return maintainId;
    }

    public void setMaintainId(Long maintainId) {
        this.maintainId = maintainId;
    }

    public Long getEquipmentTypeId() {
        return equipmentTypeId;
    }

    public void setEquipmentTypeId(Long equipmentTypeId) {
        this.equipmentTypeId = equipmentTypeId;
    }
    public String getEquipmentTypeCode() {
        return equipmentTypeCode;
    }

    public void setEquipmentTypeCode(String equipmentTypeCode) {
        this.equipmentTypeCode = equipmentTypeCode;
    }
    public String getEquipmentTypeName() {
        return equipmentTypeName;
    }

    public void setEquipmentTypeName(String equipmentTypeName) {
        this.equipmentTypeName = equipmentTypeName;
    }
    public Long getEquipmentId() {
        return equipmentId;
    }

    public void setEquipmentId(Long equipmentId) {
        this.equipmentId = equipmentId;
    }
    public String getEquipmentCode() {
        return equipmentCode;
    }

    public void setEquipmentCode(String equipmentCode) {
        this.equipmentCode = equipmentCode;
    }
    public String getEquipmentName() {
        return equipmentName;
    }

    public void setEquipmentName(String equipmentName) {
        this.equipmentName = equipmentName;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public Long getUnitId() {
        return unitId;
    }

    public void setUnitId(Long unitId) {
        this.unitId = unitId;
    }
    public String getUnit() {
        return unit;
    }

    public void setUnit(String unit) {
        this.unit = unit;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Date getLeaveFactoryDate() {
        return leaveFactoryDate;
    }

    public void setLeaveFactoryDate(Date leaveFactoryDate) {
        this.leaveFactoryDate = leaveFactoryDate;
    }
    public String getMaintainPosition() {
        return maintainPosition;
    }

    public void setMaintainPosition(String maintainPosition) {
        this.maintainPosition = maintainPosition;
    }
    public String getMaintainRequirement() {
        return maintainRequirement;
    }

    public void setMaintainRequirement(String maintainRequirement) {
        this.maintainRequirement = maintainRequirement;
    }
    public String getMaintainCost() {
        return maintainCost;
    }

    public void setMaintainCost(String maintainCost) {
        this.maintainCost = maintainCost;
    }
    public String getMaintainUser() {
        return maintainUser;
    }

    public void setMaintainUser(String maintainUser) {
        this.maintainUser = maintainUser;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

    public Long getMaintainUserId() {
        return maintainUserId;
    }

    public void setMaintainUserId(Long maintainUserId) {
        this.maintainUserId = maintainUserId;
    }

    public String getMaintainUserName() {
        return maintainUserName;
    }

    public void setMaintainUserName(String maintainUserName) {
        this.maintainUserName = maintainUserName;
    }
}
